@@ -28,11 +28,7 @@ from magnum.common import short_id
 from magnum.conductor.handlers import bay_conductor
 from magnum.conductor.handlers import ca_conductor
 from magnum.conductor.handlers import conductor_listener
-from magnum.conductor.handlers import docker_conductor
 from magnum.conductor.handlers import indirection_api
-from magnum.conductor.handlers import k8s_conductor
-from magnum.conductor.handlers import x509keypair_conductor
-from magnum.i18n import _LE
 from magnum.i18n import _LI
 from magnum import version
 
@@ -53,23 +49,11 @@ def main():
     conductor_id = short_id.generate_id()
     endpoints = [
         indirection_api.Handler(),
-        docker_conductor.Handler(),
-        k8s_conductor.Handler(),
         bay_conductor.Handler(),
-        x509keypair_conductor.Handler(),
         conductor_listener.Handler(),
         ca_conductor.Handler(),
     ]
 
-    if (not os.path.isfile(cfg.CONF.bay.k8s_atomic_template_path)
-            and not os.path.isfile(cfg.CONF.bay.k8s_coreos_template_path)):
-        LOG.error(_LE("The Heat template can not be found for either k8s "
-                      "atomic %(atomic_template)s or coreos "
-                      "(coreos_template)%s. Install template first if you "
-                      "want to create bay.") %
-                  {'atomic_template': cfg.CONF.bay.k8s_atomic_template_path,
-                   'coreos_template': cfg.CONF.bay.k8s_coreos_template_path})
-
     server = rpc_service.Service.create(cfg.CONF.conductor.topic,
                                         conductor_id, endpoints,
                                         binary='magnum-conductor')
