@@ -21,17 +21,12 @@ Includes decorator for re-raising Magnum-type exceptions.
 import functools
 import json
 import sys
-import uuid
 
 from keystoneclient import exceptions as keystone_exceptions
 from oslo_config import cfg
 from oslo_log import log as logging
-from oslo_utils import excutils
-import pecan
 import six
-import wsme
 
-from magnum.common import safe_utils
 from magnum.i18n import _
 from magnum.i18n import _LE
 
@@ -55,113 +50,6 @@ except cfg.NoSuchOptError as e:
                     group='oslo_versionedobjects')
 
 
-def wrap_exception(notifier=None, event_type=None):
-    """This decorator wraps a method to catch any exceptions.
-
-    It logs the exception as well as optionally sending
-    it to the notification system.
-    """
-    def inner(f):
-        def wrapped(self, context, *args, **kw):
-            # Don't store self or context in the payload, it now seems to
-            # contain confidential information.
-            try:
-                return f(self, context, *args, **kw)
-            except Exception as e:
-                with excutils.save_and_reraise_exception():
-                    if notifier:
-                        call_dict = safe_utils.getcallargs(f, context,
-                                                           *args, **kw)
-                        payload = dict(exception=e,
-                                       private=dict(args=call_dict)
-                                       )
-
-                        temp_type = event_type
-                        if not temp_type:
-                            # If f has multiple decorators, they must use
-                            # functools.wraps to ensure the name is
-                            # propagated.
-                            temp_type = f.__name__
-
-                        notifier.error(context, temp_type, payload)
-
-        return functools.wraps(f)(wrapped)
-    return inner
-
-
-OBFUSCATED_MSG = _('Your request could not be handled '
-                   'because of a problem in the server. '
-                   'Error Correlation id is: %s')
-
-
-def wrap_controller_exception(func, func_server_error, func_client_error):
-    """This decorator wraps controllers methods to handle exceptions:
-
-    - if an unhandled Exception or a MagnumException with an error code >=500
-    is catched, raise a http 5xx ClientSideError and correlates it with a log
-    message
-
-    - if a MagnumException is catched and its error code is <500, raise a http
-    4xx and logs the excp in debug mode
-
-    """
-    @functools.wraps(func)
-    def wrapped(*args, **kw):
-        try:
-            return func(*args, **kw)
-        except Exception as excp:
-            if isinstance(excp, MagnumException):
-                http_error_code = excp.code
-            else:
-                http_error_code = 500
-
-            if http_error_code >= 500:
-                # log the error message with its associated
-                # correlation id
-                log_correlation_id = str(uuid.uuid4())
-                LOG.error(_LE("%(correlation_id)s:%(excp)s") %
-                          {'correlation_id': log_correlation_id,
-                           'excp': str(excp)})
-                # raise a client error with an obfuscated message
-                func_server_error(log_correlation_id, http_error_code)
-            else:
-                # raise a client error the original message
-                LOG.debug(excp)
-                func_client_error(excp, http_error_code)
-    return wrapped
-
-
-def wrap_wsme_controller_exception(func):
-    """This decorator wraps wsme controllers to handle exceptions."""
-    def _func_server_error(log_correlation_id, status_code):
-        raise wsme.exc.ClientSideError(
-            six.text_type(OBFUSCATED_MSG % log_correlation_id), status_code)
-
-    def _func_client_error(excp, status_code):
-        raise wsme.exc.ClientSideError(six.text_type(excp), status_code)
-
-    return wrap_controller_exception(func,
-                                     _func_server_error,
-                                     _func_client_error)
-
-
-def wrap_pecan_controller_exception(func):
-    """This decorator wraps pecan controllers to handle exceptions."""
-    def _func_server_error(log_correlation_id, status_code):
-        pecan.response.status = status_code
-        pecan.response.text = six.text_type(OBFUSCATED_MSG %
-                                            log_correlation_id)
-
-    def _func_client_error(excp, status_code):
-        pecan.response.status = status_code
-        pecan.response.text = six.text_type(excp)
-        pecan.response.content_type = None
-
-    return wrap_controller_exception(func,
-                                     _func_server_error,
-                                     _func_client_error)
-
-
 def wrap_keystone_exception(func):
     """Wrap keystone exceptions and throw Magnum specific exceptions."""
     @functools.wraps(func)
@@ -201,18 +89,18 @@ class MagnumException(Exception):
 
         try:
             self.message = self.message % kwargs
-        except Exception as e:
+        except Exception:
             # kwargs doesn't match a variable in the message
             # log the issue and the kwargs
             LOG.exception(_LE('Exception in string format operation, '
                               'kwargs: %s') % kwargs)
             try:
                 if CONF.fatal_exception_format_errors:
-                    raise e
+                    raise
             except cfg.NoSuchOptError:
                 # Note: work around for Bug: #1447873
                 if CONF.oslo_versionedobjects.fatal_exception_format_errors:
-                    raise e
+                    raise
 
         super(MagnumException, self).__init__(self.message)
 
@@ -235,36 +123,15 @@ class ObjectNotFound(MagnumException):
     message = _("The %(name)s %(id)s could not be found.")
 
 
-class ObjectNotUnique(MagnumException):
-    message = _("The %(name)s already exists.")
-
-
 class ResourceNotFound(ObjectNotFound):
     message = _("The %(name)s resource %(id)s could not be found.")
     code = 404
 
 
-class ResourceExists(ObjectNotUnique):
-    message = _("The %(name)s resource already exists.")
-    code = 409
-
-
 class AuthorizationFailure(MagnumException):
     message = _("%(client)s connection failed. %(message)s")
 
 
-class UnsupportedObjectError(MagnumException):
-    message = _('Unsupported object type %(objtype)s')
-
-
-class IncompatibleObjectVersion(MagnumException):
-    message = _('Version %(objver)s of %(objname)s is not supported')
-
-
-class OrphanedObjectError(MagnumException):
-    message = _('Cannot call %(method)s on orphaned %(objtype)s object')
-
-
 class Invalid(MagnumException):
     message = _("Unacceptable parameters.")
     code = 400
@@ -275,7 +142,7 @@ class InvalidUUID(Invalid):
 
 
 class InvalidName(Invalid):
-    message = _("Expected a name but received %(uuid)s.")
+    message = _("Expected a name but received %(name)s.")
 
 
 class InvalidDiscoveryURL(Invalid):
@@ -287,8 +154,17 @@ class GetDiscoveryUrlFailed(MagnumException):
     message = _("Failed to get discovery url from '%(discovery_endpoint)s'.")
 
 
-class InvalidUuidOrName(Invalid):
-    message = _("Expected a name or uuid but received %(uuid)s.")
+class InvalidBayDiscoveryURL(Invalid):
+    message = _("Invalid discovery URL '%(discovery_url)s'.")
+
+
+class InvalidClusterSize(Invalid):
+    message = _("Expected cluster size %(expect_size)d but get cluster "
+                "size %(size)d from '%(discovery_url)s'.")
+
+
+class GetClusterSizeFailed(MagnumException):
+    message = _("Failed to get the size of cluster from '%(discovery_url)s'.")
 
 
 class InvalidIdentity(Invalid):
@@ -299,6 +175,10 @@ class InvalidCsr(Invalid):
     message = _("Received invalid csr %(csr)s.")
 
 
+class InvalidSubnet(Invalid):
+    message = _("Received invalid subnet %(subnet)s.")
+
+
 class HTTPNotFound(ResourceNotFound):
     pass
 
@@ -308,8 +188,9 @@ class Conflict(MagnumException):
     code = 409
 
 
-class InvalidState(Conflict):
-    message = _("Invalid resource state.")
+class ApiVersionsIntersect(MagnumException):
+    message = _("Version of %(name)s %(min_ver)s %(max_ver)s intersects "
+                "with another versions.")
 
 
 # Cannot be templated as the error syntax varies.
@@ -318,10 +199,6 @@ class InvalidParameterValue(Invalid):
     message = _("%(err)s")
 
 
-class InstanceNotFound(ResourceNotFound):
-    message = _("Instance %(instance)s could not be found.")
-
-
 class PatchError(Invalid):
     message = _("Couldn't apply patch '%(patch)s'. Reason: %(reason)s")
 
@@ -335,13 +212,6 @@ class PolicyNotAuthorized(NotAuthorized):
     message = _("Policy doesn't allow %(action)s to be performed.")
 
 
-class NotAcceptable(MagnumException):
-    # TODO(yuntongjin): We need to set response headers
-    # in the API for this exception
-    message = _("Request not acceptable.")
-    code = 406
-
-
 class InvalidMAC(Invalid):
     message = _("Expected a MAC address but received %(mac)s.")
 
@@ -359,28 +229,29 @@ class FileSystemNotSupported(MagnumException):
                 "File system %(fs)s is not supported.")
 
 
-class BayModelNotFound(ResourceNotFound):
-    message = _("Baymodel %(baymodel)s could not be found.")
+class ClusterTemplateNotFound(ResourceNotFound):
+    message = _("ClusterTemplate %(clustertemplate)s could not be found.")
 
 
-class BayModelAlreadyExists(Conflict):
-    message = _("A baymodel with UUID %(uuid)s already exists.")
+class ClusterTemplateAlreadyExists(Conflict):
+    message = _("A ClusterTemplate with UUID %(uuid)s already exists.")
 
 
-class BayModelReferenced(Invalid):
-    message = _("Baymodel %(baymodel)s is referenced by one or multiple bays.")
+class ClusterTemplateReferenced(Invalid):
+    message = _("ClusterTemplate %(clustertemplate)s is referenced by one or"
+                " multiple clusters.")
 
 
-class BaymodelPublishDenied(NotAuthorized):
-    message = _("Not authorized to set public flag for baymodel.")
+class ClusterTemplatePublishDenied(NotAuthorized):
+    message = _("Not authorized to set public flag for cluster template.")
 
 
-class BayNotFound(ResourceNotFound):
-    message = _("Bay %(bay)s could not be found.")
+class ClusterNotFound(ResourceNotFound):
+    message = _("Cluster %(cluster)s could not be found.")
 
 
-class BayAlreadyExists(Conflict):
-    message = _("A bay with UUID %(uuid)s already exists.")
+class ClusterAlreadyExists(Conflict):
+    message = _("A cluster with UUID %(uuid)s already exists.")
 
 
 class ContainerNotFound(ResourceNotFound):
@@ -407,24 +278,6 @@ class PodCreationFailed(Invalid):
     message = _("Pod creation failed in Bay %(bay_uuid)s.")
 
 
-class ReplicationControllerNotFound(ResourceNotFound):
-    message = _("ReplicationController %(rc)s could not be found.")
-
-
-class ReplicationControllerAlreadyExists(Conflict):
-    message = _("A ReplicationController with UUID %(uuid)s already exists.")
-
-
-class ReplicationControllerListNotFound(ResourceNotFound):
-    message = _("ReplicationController list could not be found"
-                " for Bay %(bay_uuid)s.")
-
-
-class ReplicationControllerCreationFailed(Invalid):
-    message = _("ReplicationController creation failed"
-                " for Bay %(bay_uuid)s.")
-
-
 class ServiceNotFound(ResourceNotFound):
     message = _("Service %(service)s could not be found.")
 
@@ -502,7 +355,7 @@ class KubernetesAPIFailed(MagnumException):
 
 
 class X509KeyPairNotFound(ResourceNotFound):
-    message = _("A key pair %(keypair)s could not be found.")
+    message = _("A key pair %(x509keypair)s could not be found.")
 
 
 class X509KeyPairAlreadyExists(Conflict):
@@ -529,8 +382,12 @@ class MagnumServiceAlreadyExists(Conflict):
     message = _("A magnum service with ID %(id)s already exists.")
 
 
-class UnsupportedK8sMemoryFormat(MagnumException):
-    message = _("Unsupported memory format for k8s bay.")
+class UnsupportedK8sQuantityFormat(MagnumException):
+    message = _("Unsupported quantity format for k8s bay.")
+
+
+class UnsupportedDockerQuantityFormat(MagnumException):
+    message = _("Unsupported quantity format for Swarm bay.")
 
 
 class FlavorNotFound(ResourceNotFound):
@@ -539,9 +396,10 @@ class FlavorNotFound(ResourceNotFound):
     code = 400
 
 
-class NetworkNotFound(ResourceNotFound):
+class ExternalNetworkNotFound(ResourceNotFound):
     """The code here changed to 400 according to the latest document."""
-    message = _("Unable to find network %(network)s.")
+    """"Ensure the network is not private."""
+    message = _("Unable to find external network %(network)s.")
     code = 400
 
 
@@ -569,3 +427,11 @@ class QuotaAlreadyExists(Conflict):
 
 class RegionsListFailed(MagnumException):
     message = _("Failed to list regions.")
+
+
+class TrusteeOrTrustToBayFailed(MagnumException):
+    message = _("Failed to create trustee or trust for Bay: %(bay_uuid)s")
+
+
+class CertificatesToBayFailed(MagnumException):
+    message = _("Failed to create certificates for Bay: %(bay_uuid)s")
