@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import socket
-
 from oslo_config import cfg
 from oslo_log import log as logging
 
@@ -23,7 +21,7 @@ from magnum.i18n import _
 
 service_opts = [
     cfg.StrOpt('host',
-               default=socket.getfqdn(),
+               default=None,
                help=_('Name of this node. This can be an opaque identifier. '
                       'It is not necessarily a hostname, FQDN, or IP address. '
                       'However, the node name must be valid within '
