@@ -15,29 +15,17 @@
 from magnum.objects import bay
 from magnum.objects import baymodel
 from magnum.objects import certificate
-from magnum.objects import container
 from magnum.objects import magnum_service
-from magnum.objects import pod
-from magnum.objects import replicationcontroller as rc
-from magnum.objects import service
 from magnum.objects import x509keypair
 
 
-Container = container.Container
 Bay = bay.Bay
 BayModel = baymodel.BayModel
 MagnumService = magnum_service.MagnumService
-Pod = pod.Pod
-ReplicationController = rc.ReplicationController
-Service = service.Service
 X509KeyPair = x509keypair.X509KeyPair
 Certificate = certificate.Certificate
 __all__ = (Bay,
            BayModel,
-           Container,
            MagnumService,
-           Pod,
-           ReplicationController,
-           Service,
            X509KeyPair,
            Certificate)
