@@ -32,7 +32,9 @@ class TestBayConductorWithK8s(base.TestCase):
             'dns_nameserver': 'dns_nameserver',
             'external_network_id': 'external_network_id',
             'network_driver': 'network_driver',
+            'volume_driver': 'volume_driver',
             'docker_volume_size': 20,
+            'docker_storage_driver': 'devicemapper',
             'cluster_distro': 'fedora-atomic',
             'coe': 'kubernetes',
             'token': None,
@@ -41,12 +43,16 @@ class TestBayConductorWithK8s(base.TestCase):
             'no_proxy': 'no_proxy',
             'labels': {'flannel_network_cidr': '10.101.0.0/16',
                        'flannel_network_subnetlen': '26',
-                       'flannel_use_vxlan': 'yes'},
+                       'flannel_backend': 'vxlan'},
             'tls_disabled': False,
-            'server_type': 'vm'
+            'server_type': 'vm',
+            'registry_enabled': False,
+            'insecure_registry': '10.0.0.1:5000',
+            'master_lb_enabled': False,
+            'floating_ip_enabled': False,
         }
         self.bay_dict = {
-            'uuid': 'bay-xx-xx-xx-xx',
+            'uuid': '5d12f6fd-a196-4bf0-ae4c-1f639a523a52',
             'baymodel_id': 'xx-xx-xx-xx',
             'name': 'bay1',
             'stack_id': 'xx-xx-xx-xx',
@@ -62,10 +68,8 @@ class TestBayConductorWithK8s(base.TestCase):
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
             'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
+            'coe_version': 'fake-version',
         }
-        cfg.CONF.set_override('trustee_domain_id',
-                              '3527620c-b220-4f37-9ebc-6e63a81a9b2f',
-                              group='trust')
         self.context.auth_url = 'http://192.168.10.10:5000/v3'
         self.context.user_name = 'fake_user'
         self.context.tenant = 'fake_tenant'
@@ -74,20 +78,25 @@ class TestBayConductorWithK8s(base.TestCase):
         self.addCleanup(osc_patcher.stop)
         self.mock_osc = mock.MagicMock()
         self.mock_osc.magnum_url.return_value = 'http://127.0.0.1:9511/v1'
+        self.mock_osc.cinder_region_name.return_value = 'RegionOne'
+        self.mock_keystone = mock.MagicMock()
+        self.mock_keystone.trustee_domain_id = 'trustee_domain_id'
+        self.mock_osc.keystone.return_value = self.mock_keystone
         self.mock_osc_class.return_value = self.mock_osc
-        mock_stack = self.mock_osc.heat.return_value.stacks.get.return_value
-        mock_stack.parameters = {'user_token': 'fake_token'}
 
+    @patch('requests.get')
     @patch('magnum.objects.BayModel.get_by_uuid')
     def test_extract_template_definition(
             self,
-            mock_objects_baymodel_get_by_uuid):
+            mock_objects_baymodel_get_by_uuid,
+            mock_get):
         self._test_extract_template_definition(
-            mock_objects_baymodel_get_by_uuid)
+            mock_objects_baymodel_get_by_uuid, mock_get)
 
     def _test_extract_template_definition(
             self,
             mock_objects_baymodel_get_by_uuid,
+            mock_get,
             missing_attr=None):
         if missing_attr in self.baymodel_dict:
             self.baymodel_dict[missing_attr] = None
@@ -95,18 +104,26 @@ class TestBayConductorWithK8s(base.TestCase):
             self.bay_dict[missing_attr] = None
         baymodel = objects.BayModel(self.context, **self.baymodel_dict)
         mock_objects_baymodel_get_by_uuid.return_value = baymodel
+        expected_result = str('{"action":"get","node":{"key":"test","value":'
+                              '"1","modifiedIndex":10,"createdIndex":10}}')
+        mock_resp = mock.MagicMock()
+        mock_resp.text = expected_result
+        mock_get.return_value = mock_resp
         bay = objects.Bay(self.context, **self.bay_dict)
 
         (template_path,
-         definition) = bay_conductor._extract_template_definition(self.context,
-                                                                  bay)
+         definition,
+         env_files) = bay_conductor._extract_template_definition(self.context,
+                                                                 bay)
 
         mapping = {
             'dns_nameserver': 'dns_nameserver',
             'image_id': 'server_image',
             'flavor_id': 'minion_flavor',
             'docker_volume_size': 'docker_volume_size',
+            'docker_storage_driver': 'docker_storage_driver',
             'network_driver': 'network_driver',
+            'volume_driver': 'volume_driver',
             'master_flavor_id': 'master_flavor',
             'apiserver_port': '',
             'node_count': 'number_of_minions',
@@ -114,19 +131,20 @@ class TestBayConductorWithK8s(base.TestCase):
             'discovery_url': 'discovery_url',
             'labels': {'flannel_network_cidr': '10.101.0.0/16',
                        'flannel_network_subnetlen': '26',
-                       'flannel_use_vxlan': 'yes'},
+                       'flannel_backend': 'vxlan'},
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
-            'user_token': self.context.auth_token,
             'bay_uuid': self.bay_dict['uuid'],
             'magnum_url': self.mock_osc.magnum_url.return_value,
             'tls_disabled': False,
+            'insecure_registry': '10.0.0.1:5000',
         }
         expected = {
             'ssh_key_name': 'keypair_id',
             'external_network': 'external_network_id',
             'network_driver': 'network_driver',
+            'volume_driver': 'volume_driver',
             'dns_nameserver': 'dns_nameserver',
             'server_image': 'image_id',
             'minion_flavor': 'flavor_id',
@@ -134,43 +152,129 @@ class TestBayConductorWithK8s(base.TestCase):
             'number_of_minions': 1,
             'number_of_masters': 1,
             'docker_volume_size': 20,
+            'docker_storage_driver': 'devicemapper',
             'discovery_url': 'https://discovery.etcd.io/test',
             'flannel_network_cidr': '10.101.0.0/16',
             'flannel_network_subnetlen': '26',
-            'flannel_use_vxlan': 'yes',
+            'flannel_backend': 'vxlan',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
             'tenant_name': 'fake_tenant',
             'username': 'fake_user',
-            'user_token': 'fake_token',
             'bay_uuid': self.bay_dict['uuid'],
             'magnum_url': self.mock_osc.magnum_url.return_value,
+            'region_name': self.mock_osc.cinder_region_name.return_value,
             'tls_disabled': False,
-            'trustee_domain_id': '3527620c-b220-4f37-9ebc-6e63a81a9b2f',
+            'registry_enabled': False,
+            'trustee_domain_id': self.mock_keystone.trustee_domain_id,
             'trustee_username': 'fake_trustee',
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
             'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
-            'auth_url': 'http://192.168.10.10:5000/v3'
+            'auth_url': 'http://192.168.10.10:5000/v3',
+            'insecure_registry_url': '10.0.0.1:5000',
+            'kube_version': 'fake-version',
         }
         if missing_attr is not None:
             expected.pop(mapping[missing_attr], None)
 
         self.assertEqual(expected, definition)
+        self.assertEqual(
+            ['../../common/templates/environments/no_master_lb.yaml',
+             '../../common/templates/environments/disable_floating_ip.yaml'],
+            env_files)
 
+    @patch('requests.get')
+    @patch('magnum.objects.BayModel.get_by_uuid')
+    def test_extract_template_definition_with_registry(
+            self,
+            mock_objects_baymodel_get_by_uuid,
+            mock_get):
+        self.baymodel_dict['registry_enabled'] = True
+        baymodel = objects.BayModel(self.context, **self.baymodel_dict)
+        mock_objects_baymodel_get_by_uuid.return_value = baymodel
+        expected_result = str('{"action":"get","node":{"key":"test","value":'
+                              '"1","modifiedIndex":10,"createdIndex":10}}')
+        mock_resp = mock.MagicMock()
+        mock_resp.text = expected_result
+        mock_get.return_value = mock_resp
+        bay = objects.Bay(self.context, **self.bay_dict)
+
+        cfg.CONF.set_override('swift_region',
+                              'RegionOne',
+                              group='docker_registry')
+
+        (template_path,
+         definition,
+         env_files) = bay_conductor._extract_template_definition(self.context,
+                                                                 bay)
+
+        expected = {
+            'auth_url': 'http://192.168.10.10:5000/v3',
+            'bay_uuid': '5d12f6fd-a196-4bf0-ae4c-1f639a523a52',
+            'discovery_url': 'https://discovery.etcd.io/test',
+            'dns_nameserver': 'dns_nameserver',
+            'docker_storage_driver': 'devicemapper',
+            'docker_volume_size': 20,
+            'external_network': 'external_network_id',
+            'flannel_backend': 'vxlan',
+            'flannel_network_cidr': '10.101.0.0/16',
+            'flannel_network_subnetlen': '26',
+            'http_proxy': 'http_proxy',
+            'https_proxy': 'https_proxy',
+            'magnum_url': 'http://127.0.0.1:9511/v1',
+            'master_flavor': 'master_flavor_id',
+            'minion_flavor': 'flavor_id',
+            'network_driver': 'network_driver',
+            'no_proxy': 'no_proxy',
+            'number_of_masters': 1,
+            'number_of_minions': 1,
+            'region_name': 'RegionOne',
+            'registry_container': 'docker_registry',
+            'registry_enabled': True,
+            'server_image': 'image_id',
+            'ssh_key_name': 'keypair_id',
+            'swift_region': 'RegionOne',
+            'tenant_name': 'fake_tenant',
+            'tls_disabled': False,
+            'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
+            'trustee_domain_id': self.mock_keystone.trustee_domain_id,
+            'trustee_password': 'fake_trustee_password',
+            'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
+            'trustee_username': 'fake_trustee',
+            'username': 'fake_user',
+            'volume_driver': 'volume_driver',
+            'insecure_registry_url': '10.0.0.1:5000',
+            'kube_version': 'fake-version',
+        }
+
+        self.assertEqual(expected, definition)
+        self.assertEqual(
+            ['../../common/templates/environments/no_master_lb.yaml',
+             '../../common/templates/environments/disable_floating_ip.yaml'],
+            env_files)
+
+    @patch('requests.get')
     @patch('magnum.objects.BayModel.get_by_uuid')
     def test_extract_template_definition_coreos_with_disovery(
             self,
-            mock_objects_baymodel_get_by_uuid):
+            mock_objects_baymodel_get_by_uuid,
+            mock_get):
         self.baymodel_dict['cluster_distro'] = 'coreos'
         baymodel = objects.BayModel(self.context, **self.baymodel_dict)
         mock_objects_baymodel_get_by_uuid.return_value = baymodel
+        expected_result = str('{"action":"get","node":{"key":"test","value":'
+                              '"1","modifiedIndex":10,"createdIndex":10}}')
+        mock_resp = mock.MagicMock()
+        mock_resp.text = expected_result
+        mock_get.return_value = mock_resp
         bay = objects.Bay(self.context, **self.bay_dict)
 
         (template_path,
-         definition) = bay_conductor._extract_template_definition(self.context,
-                                                                  bay)
+         definition,
+         env_files) = bay_conductor._extract_template_definition(self.context,
+                                                                 bay)
 
         expected = {
             'ssh_key_name': 'keypair_id',
@@ -182,22 +286,31 @@ class TestBayConductorWithK8s(base.TestCase):
             'number_of_minions': 1,
             'number_of_masters': 1,
             'network_driver': 'network_driver',
+            'volume_driver': 'volume_driver',
             'discovery_url': 'https://discovery.etcd.io/test',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
             'flannel_network_cidr': '10.101.0.0/16',
             'flannel_network_subnetlen': '26',
-            'flannel_use_vxlan': 'yes',
+            'flannel_backend': 'vxlan',
             'tls_disabled': False,
-            'trustee_domain_id': '3527620c-b220-4f37-9ebc-6e63a81a9b2f',
+            'registry_enabled': False,
+            'trustee_domain_id': self.mock_keystone.trustee_domain_id,
             'trustee_username': 'fake_trustee',
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
             'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
-            'auth_url': 'http://192.168.10.10:5000/v3'
+            'auth_url': 'http://192.168.10.10:5000/v3',
+            'bay_uuid': self.bay_dict['uuid'],
+            'magnum_url': self.mock_osc.magnum_url.return_value,
+            'insecure_registry_url': '10.0.0.1:5000',
+            'kube_version': 'fake-version',
         }
         self.assertEqual(expected, definition)
+        self.assertEqual(
+            ['../../common/templates/environments/no_master_lb.yaml'],
+            env_files)
 
     @patch('requests.get')
     @patch('magnum.objects.BayModel.get_by_uuid')
@@ -214,8 +327,9 @@ class TestBayConductorWithK8s(base.TestCase):
         bay = objects.Bay(self.context, **self.bay_dict)
 
         (template_path,
-         definition) = bay_conductor._extract_template_definition(self.context,
-                                                                  bay)
+         definition,
+         env_files) = bay_conductor._extract_template_definition(self.context,
+                                                                 bay)
 
         expected = {
             'ssh_key_name': 'keypair_id',
@@ -227,85 +341,129 @@ class TestBayConductorWithK8s(base.TestCase):
             'number_of_minions': 1,
             'number_of_masters': 1,
             'network_driver': 'network_driver',
+            'volume_driver': 'volume_driver',
             'discovery_url': 'http://tokentest/h1/h2/h3',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
             'flannel_network_cidr': '10.101.0.0/16',
             'flannel_network_subnetlen': '26',
-            'flannel_use_vxlan': 'yes',
+            'flannel_backend': 'vxlan',
             'tls_disabled': False,
-            'trustee_domain_id': '3527620c-b220-4f37-9ebc-6e63a81a9b2f',
+            'registry_enabled': False,
+            'trustee_domain_id': self.mock_keystone.trustee_domain_id,
             'trustee_username': 'fake_trustee',
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
             'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
-            'auth_url': 'http://192.168.10.10:5000/v3'
+            'auth_url': 'http://192.168.10.10:5000/v3',
+            'bay_uuid': self.bay_dict['uuid'],
+            'magnum_url': self.mock_osc.magnum_url.return_value,
+            'insecure_registry_url': '10.0.0.1:5000',
+            'kube_version': 'fake-version',
         }
         self.assertEqual(expected, definition)
+        self.assertEqual(
+            ['../../common/templates/environments/no_master_lb.yaml'],
+            env_files)
 
+    @patch('requests.get')
     @patch('magnum.objects.BayModel.get_by_uuid')
     def test_extract_template_definition_without_dns(
             self,
-            mock_objects_baymodel_get_by_uuid):
+            mock_objects_baymodel_get_by_uuid,
+            mock_get):
         self._test_extract_template_definition(
             mock_objects_baymodel_get_by_uuid,
+            mock_get,
             missing_attr='dns_nameserver')
 
+    @patch('requests.get')
     @patch('magnum.objects.BayModel.get_by_uuid')
     def test_extract_template_definition_without_server_image(
             self,
-            mock_objects_baymodel_get_by_uuid):
+            mock_objects_baymodel_get_by_uuid,
+            mock_get):
         self._test_extract_template_definition(
             mock_objects_baymodel_get_by_uuid,
+            mock_get,
             missing_attr='image_id')
 
+    @patch('requests.get')
     @patch('magnum.objects.BayModel.get_by_uuid')
     def test_extract_template_definition_without_minion_flavor(
             self,
-            mock_objects_baymodel_get_by_uuid):
+            mock_objects_baymodel_get_by_uuid,
+            mock_get):
         self._test_extract_template_definition(
             mock_objects_baymodel_get_by_uuid,
+            mock_get,
             missing_attr='flavor_id')
 
+    @patch('requests.get')
     @patch('magnum.objects.BayModel.get_by_uuid')
     def test_extract_template_definition_without_docker_volume_size(
             self,
-            mock_objects_baymodel_get_by_uuid):
+            mock_objects_baymodel_get_by_uuid,
+            mock_get):
         self._test_extract_template_definition(
             mock_objects_baymodel_get_by_uuid,
+            mock_get,
             missing_attr='docker_volume_size')
 
+    @patch('requests.get')
+    @patch('magnum.objects.BayModel.get_by_uuid')
+    def test_extract_template_definition_without_docker_storage_driver(
+            self,
+            mock_objects_baymodel_get_by_uuid,
+            mock_get):
+        self._test_extract_template_definition(
+            mock_objects_baymodel_get_by_uuid,
+            mock_get,
+            missing_attr='docker_storage_driver')
+
+    @patch('requests.get')
     @patch('magnum.objects.BayModel.get_by_uuid')
     def test_extract_template_definition_without_master_flavor(
             self,
-            mock_objects_baymodel_get_by_uuid):
+            mock_objects_baymodel_get_by_uuid,
+            mock_get):
         self._test_extract_template_definition(
             mock_objects_baymodel_get_by_uuid,
+            mock_get,
             missing_attr='master_flavor_id')
 
+    @patch('requests.get')
     @patch('magnum.objects.BayModel.get_by_uuid')
     def test_extract_template_definition_without_apiserver_port(
             self,
-            mock_objects_baymodel_get_by_uuid):
+            mock_objects_baymodel_get_by_uuid,
+            mock_get):
         self._test_extract_template_definition(
             mock_objects_baymodel_get_by_uuid,
+            mock_get,
             missing_attr='apiserver_port')
 
+    @patch('requests.get')
     @patch('magnum.objects.BayModel.get_by_uuid')
     def test_extract_template_definition_without_node_count(
             self,
-            mock_objects_baymodel_get_by_uuid):
+            mock_objects_baymodel_get_by_uuid,
+            mock_get):
         self._test_extract_template_definition(
             mock_objects_baymodel_get_by_uuid,
+            mock_get,
             missing_attr='node_count')
 
+    @patch('requests.get')
     @patch('magnum.objects.BayModel.get_by_uuid')
     def test_extract_template_definition_without_master_count(
             self,
-            mock_objects_baymodel_get_by_uuid):
+            mock_objects_baymodel_get_by_uuid,
+            mock_get):
         self._test_extract_template_definition(
             mock_objects_baymodel_get_by_uuid,
+            mock_get,
             missing_attr='master_count')
 
     @patch('requests.get')
@@ -327,8 +485,9 @@ class TestBayConductorWithK8s(base.TestCase):
         reqget.return_value = mock_req
 
         (template_path,
-         definition) = bay_conductor._extract_template_definition(self.context,
-                                                                  bay)
+         definition,
+         env_files) = bay_conductor._extract_template_definition(self.context,
+                                                                 bay)
 
         expected = {
             'ssh_key_name': 'keypair_id',
@@ -340,28 +499,37 @@ class TestBayConductorWithK8s(base.TestCase):
             'number_of_minions': 1,
             'number_of_masters': 1,
             'network_driver': 'network_driver',
+            'volume_driver': 'volume_driver',
             'docker_volume_size': 20,
+            'docker_storage_driver': 'devicemapper',
             'discovery_url': 'https://address/token',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
             'flannel_network_cidr': '10.101.0.0/16',
             'flannel_network_subnetlen': '26',
-            'flannel_use_vxlan': 'yes',
+            'flannel_backend': 'vxlan',
             'tenant_name': 'fake_tenant',
             'username': 'fake_user',
-            'user_token': 'fake_token',
             'bay_uuid': self.bay_dict['uuid'],
             'magnum_url': self.mock_osc.magnum_url.return_value,
+            'region_name': self.mock_osc.cinder_region_name.return_value,
             'tls_disabled': False,
-            'trustee_domain_id': '3527620c-b220-4f37-9ebc-6e63a81a9b2f',
+            'registry_enabled': False,
+            'trustee_domain_id': self.mock_keystone.trustee_domain_id,
             'trustee_username': 'fake_trustee',
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
             'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
-            'auth_url': 'http://192.168.10.10:5000/v3'
+            'auth_url': 'http://192.168.10.10:5000/v3',
+            'insecure_registry_url': '10.0.0.1:5000',
+            'kube_version': 'fake-version',
         }
         self.assertEqual(expected, definition)
+        self.assertEqual(
+            ['../../common/templates/environments/no_master_lb.yaml',
+             '../../common/templates/environments/disable_floating_ip.yaml'],
+            env_files)
         reqget.assert_called_once_with('http://etcd/test?size=1')
 
     @patch('magnum.common.short_id.generate_id')
@@ -383,7 +551,7 @@ class TestBayConductorWithK8s(base.TestCase):
         mock_get_template_contents.return_value = [
             mock_tpl_files, expected_template_contents]
         mock_extract_template_definition.return_value = ('template/path',
-                                                         {})
+                                                         {}, [])
         mock_heat_client = mock.MagicMock()
         mock_osc = mock.MagicMock()
         mock_osc.heat.return_value = mock_heat_client
@@ -398,6 +566,7 @@ class TestBayConductorWithK8s(base.TestCase):
             'parameters': {},
             'template': expected_template_contents,
             'files': {},
+            'environment_files': [],
             'timeout_mins': expected_timeout
         }
         mock_heat_client.stacks.create.assert_called_once_with(**expected_args)
@@ -422,7 +591,7 @@ class TestBayConductorWithK8s(base.TestCase):
         mock_get_template_contents.return_value = [
             mock_tpl_files, expected_template_contents]
         mock_extract_template_definition.return_value = ('template/path',
-                                                         {})
+                                                         {}, [])
         mock_heat_client = mock.MagicMock()
         mock_osc = mock.MagicMock()
         mock_osc.heat.return_value = mock_heat_client
@@ -437,6 +606,7 @@ class TestBayConductorWithK8s(base.TestCase):
             'parameters': {},
             'template': expected_template_contents,
             'files': {},
+            'environment_files': [],
             'timeout_mins': expected_timeout
         }
         mock_heat_client.stacks.create.assert_called_once_with(**expected_args)
@@ -456,13 +626,13 @@ class TestBayConductorWithK8s(base.TestCase):
         expected_template_contents = 'template_contents'
         dummy_bay_name = 'expected_stack_name'
         bay_timeout = 0
-        expected_timeout = None
+        expected_timeout = cfg.CONF.bay_heat.bay_create_timeout
 
         mock_tpl_files = {}
         mock_get_template_contents.return_value = [
             mock_tpl_files, expected_template_contents]
         mock_extract_template_definition.return_value = ('template/path',
-                                                         {})
+                                                         {}, [])
         mock_heat_client = mock.MagicMock()
         mock_osc = mock.MagicMock()
         mock_osc.heat.return_value = mock_heat_client
@@ -477,6 +647,7 @@ class TestBayConductorWithK8s(base.TestCase):
             'parameters': {},
             'template': expected_template_contents,
             'files': {},
+            'environment_files': [],
             'timeout_mins': expected_timeout
         }
         mock_heat_client.stacks.create.assert_called_once_with(**expected_args)
@@ -495,7 +666,7 @@ class TestBayConductorWithK8s(base.TestCase):
         mock_get_template_contents.return_value = [
             mock_tpl_files, expected_template_contents]
         mock_extract_template_definition.return_value = ('template/path',
-                                                         {})
+                                                         {}, [])
         mock_heat_client = mock.MagicMock()
         mock_osc = mock.MagicMock()
         mock_osc.heat.return_value = mock_heat_client
@@ -507,7 +678,9 @@ class TestBayConductorWithK8s(base.TestCase):
         expected_args = {
             'parameters': {},
             'template': expected_template_contents,
-            'files': {}
+            'files': {},
+            'environment_files': [],
+            'disable_rollback': True
         }
         mock_heat_client.stacks.update.assert_called_once_with(mock_stack_id,
                                                                **expected_args)
